@@ -1,12 +1,12 @@
 package Dancer2::Plugin::DBIx::Class;
 use Modern::Perl;
-our $VERSION = '1.1000'; # VERSION
+our $VERSION = '1.1001'; # VERSION
 our $AUTHORITY = 'cpan:GEEKRUTH'; # AUTHORITY
 # ABSTRACT: syntactic sugar for DBIx::Class in Dancer2, optionally with DBIx::Class::Schema::ResultSetNames
 use Carp;
 use Class::C3::Componentised;
 use Dancer2::Plugin::DBIx::Class::ExportBuilder;
-use Dancer2::Plugin;
+use Dancer2::Plugin 0.154000;
 
 my $_schemas = {};
 
@@ -134,7 +134,7 @@ Dancer2::Plugin::DBIx::Class - syntactic sugar for DBIx::Class in Dancer2, optio
 
 =head1 VERSION
 
-version 1.1000
+version 1.1001
 
 =head1 SYNOPSIS
 
