@@ -8,7 +8,6 @@ __PACKAGE__->table('cars');
 __PACKAGE__->add_columns(qw(id model human));
 __PACKAGE__->set_primary_key('id');
 
-__PACKAGE__->belongs_to( 'human' => 'FirstSchemaWith::Result::Human',
-   'human' );
+__PACKAGE__->belongs_to('human' => 'FirstSchemaWith::Result::Human', 'human');
 
 1;
